#!/bin/bash
# DRSM installation script
# Last modified: 05/05/2017

cd ../
BASEdir=$(pwd)
if [ "${1}" != "" ]; then BASEdir="${1}"; fi

if [ ! -d ${BASEdir}/bin ] || [ ! -d ${BASEdir}/etc ] || [ ! -d ${BASEdir}/utils ] || [ ! -d ${BASEdir}/www ]; then
    echo "ERROR - Bad DRSM ${BASEdir} base directory"
    exit 1
fi

echo ""
echo "EULA: The DataReel system admin monitor is free software distributed"
echo "under the terms of the GNU General Public License version 3 or any"
echo "later version. The accuracy and usability of this software is not"
echo "guaranteed. By installing this software you are accepting all risks to"
echo "your operating systems, software, and hardware. This software is"
echo "distributed in the hope that it will be useful, but WITHOUT ANY"
echo "WARRANTY; without even the implied warranty of MERCHANTABILITY or"
echo "FITNESS FOR A PARTICULAR PURPOSE."
echo ""

echo -n "Accept EULA (Yes/no)> "
read prompt
if [ "${prompt^^}" == "YES" ] || [ "${prompt^}" == "Y" ];
then
    echo "EULA accepted, continue install"
else
    echo "EULA not accepted"
    echo "Exiting with no action taken"
    exit 1
fi

if [ -f ${HOME}/.drsm.sh ]; then
    echo "INFO - Using config override file ${HOME}/.drsm.sh"
    CONFIG_FILE=${HOME}/.drsm.sh
else
    echo "INFO - Using default config ${BASEdir}/etc/drsm.sh"
    CONFIG_FILE=${BASEdir}/etc/drsm.sh
fi

if [ ! -f ${CONFIG_FILE} ]; then
    echo "Missing base config ${CONFIG_FILE}"
    exit 1
fi

source ${CONFIG_FILE}

USERNAME=$(whoami)

if [ "${USERNAME}" != "${SYSADMIN_USERNAME}" ]; then 
    if [ "${USERNAME}" != "root" ]; then
	echo "ERROR - You must ${SYSADMIN_USERNAME} or root to install"
	echo "ERROR - Check your DRSM config ${CONFIG_FILE}"
    exit 1
    fi
fi

echo "Installing DSRM to ${DRSMHOME}"
mkdir -pv ${DRSMHOME}
if [ $? -ne 0 ]; then 
    echo "ERROR - Cannot make install DIR ${DRSMHOME}"
    echo "ERROR - Check your DRSM config ${CONFIG_FILE}"
    exit 1
fi

dirs="bin etc mysql utils www"
for d in ${dirs}
do
    cp -rfv ${BASEdir}/${d} ${DRSMHOME}/.
    if [ $? -ne 0 ]; then 
	echo "ERROR - Cannot install ${BASEdir}/${d} to ${DRSMHOME}/${d}"
	exit 1
    fi
    if [ "${USERNAME}" != "${SYSADMIN_USERNAME}" ]; then 
	chmod 775 ${DRSMHOME}/${d}
	chown ${SYSADMIN_USERNAME}:${SYSADMIN_GROUPNAME} ${DRSMHOME}/${d}
	chown ${SYSADMIN_USERNAME}:${SYSADMIN_GROUPNAME} ${DRSMHOME}/${d}/*
    fi
done 

find ${DRSMHOME} -name "*.sh" -print | xargs chmod 755

files="README.txt version.txt license.txt"
for f in ${files}
do
    cp -fv ${BASEdir}/${f} ${DRSMHOME}/${f}
    if [ $? -ne 0 ]; then 
	echo "ERROR - Cannot install ${f} to ${DRSMHOME}/${f}"
	exit 1
    fi
    if [ "${USERNAME}" != "${SYSADMIN_USERNAME}" ]; then 
	chmod 644 ${DRSMHOME}/${f}
	chown ${SYSADMIN_USERNAME}:${SYSADMIN_GROUPNAME} ${DRSMHOME}/${f}
    fi
done 

echo "Creating Web directories"
dirs="${WWWdir}/php ${REPORTdir}/systems ${REPORTarchive} ${CONFIGdir} ${SITEincludes}"
for d in ${dirs}
do
    mkdir -pv ${d}
    if [ $? -ne 0 ]; then 
	echo "ERROR - Cannot make DIR ${d}"
	echo "ERROR - Check your DRSM config ${CONFIG_FILE}"
	exit 1
    fi
    chmod 775 ${d}
    chown ${SYSADMIN_USERNAME}:${SYSADMIN_GROUPNAME} ${d}
done 

chmod 775 ${WWWdir} ${REPORTdir}
chown ${SYSADMIN_USERNAME}:${SYSADMIN_GROUPNAME} ${WWWdir} ${REPORTdir}

echo "Creating default PHP configuration"
fname="drsm.php"
if [ -f ${CONFIGdir}/${fname} ]; then 
    	echo "INFO - Config file exists ${CONFIGdir}/${fname}"
	echo "INFO - Will not overwrite existing PHP config"
	fname="drsm.php_install_new"
fi
cat /dev/null > ${CONFIGdir}/${fname}
echo '<?php ' >> ${CONFIGdir}/${fname}
echo '// DRSM PHP config ' >> ${CONFIGdir}/${fname}
echo '// Auto generated by DRSM install script ' >> ${CONFIGdir}/${fname}
echo -n '$WWWdir = ' >> ${CONFIGdir}/${fname}; echo "'${WWWdir}';" >> ${CONFIGdir}/${fname}
echo -n '$WWWvpath = ' >> ${CONFIGdir}/${fname}; echo "'${WWWvpath}';" >> ${CONFIGdir}/${fname}
echo -n '$REPORTdir = ' >> ${CONFIGdir}/${fname}; echo "'${REPORTdir}';" >> ${CONFIGdir}/${fname}
echo -n '$REPORTvpath = ' >> ${CONFIGdir}/${fname}; echo "'${REPORTvpath}';" >> ${CONFIGdir}/${fname}
echo -n '$REPORTarchive = ' >> ${CONFIGdir}/${fname}; echo "'${REPORTarchive}';" >> ${CONFIGdir}/${fname}
echo -n '$REPORTarchivevpath = ' >> ${CONFIGdir}/${fname}; echo "'${REPORTarchivevpath}';" >> ${CONFIGdir}/${fname}
echo -n '$CONFIGdir = ' >> ${CONFIGdir}/${fname}; echo "'${CONFIGdir}';" >> ${CONFIGdir}/${fname}
echo -n '$SITEincludes = ' >> ${CONFIGdir}/${fname}; echo "'${SITEincludes}';" >> ${CONFIGdir}/${fname}
echo '?>' >> ${CONFIGdir}/${fname}
chmod 664 ${CONFIGdir}/${fname}
chown ${SYSADMIN_USERNAME}:${SYSADMIN_GROUPNAME} ${CONFIGdir}/${fname}

echo "Installing PHP code"
files="checks.php \
default_footer.php \
default_header.php \
index.php \
query_post_validation.php \
readreport.php \
reports.php"

for f in ${files}
do
    cp -fv ${BASEdir}/www/php/${f} ${WWWdir}/php/${f}
    chmod 664 ${WWWdir}/php/${f}
    chown ${SYSADMIN_USERNAME}:${SYSADMIN_GROUPNAME} ${WWWdir}/php/${f}
    sed -i s,../config/drsm.php,${CONFIGdir}/drsm.php,g ${WWWdir}/php/${f}
done 

echo "Copying WWW image files"
mkdir -pv ${WWWdir}/images
cp -fv ${BASEdir}/www/images/* ${WWWdir}/images/.
chmod 775 ${WWWdir}/images
chmod 664 ${WWWdir}/images/*
chown ${SYSADMIN_USERNAME}:${SYSADMIN_GROUPNAME} ${WWWdir}/images/*
if [ ! -f  ${WWWdir}/index.php ]; then
    echo "Creating default index page"
    cat /dev/null > ${WWWdir}/index.php
    echo '<?php ' >> ${WWWdir}/index.php
    echo "include('${WWWdir}/php/index.php');" >> ${WWWdir}/index.php 
    echo '?>' >> ${WWWdir}/index.php
    echo "" >> ${WWWdir}/index.php
    chmod 664 ${WWWdir}/index.php
    chown ${SYSADMIN_USERNAME}:${SYSADMIN_GROUPNAME} ${WWWdir}/index.php
fi
 
echo "Installing sysadmin dat templates"
files="systems.dat dev_systems.dat"
for f in ${files}
do
    if [ -f ${CONFIGdir}/${f} ]; then 
	echo "INFO - Config file exists ${CONFIGdir}/${f}"
	echo "INFO - Will not overwrite existing DB file"
	cp -f ${CONFIGdir}/${f} ${CONFIGdir}/${f}_install_new
	chmod 664 ${CONFIGdir}/${f}_install_new
	chown ${SYSADMIN_USERNAME}:${SYSADMIN_GROUPNAME} ${CONFIGdir}/${f}_install_new

    else
	cp -fv ${BASEdir}/www/config/${f} ${CONFIGdir}/${f}
	chmod 664 ${CONFIGdir}/${f}
	chown ${SYSADMIN_USERNAME}:${SYSADMIN_GROUPNAME} ${CONFIGdir}/${f}
    fi
done 

echo "Install complete"
echo ""
exit 0
